@@ -16,13 +16,11 @@ from wpiformat.config import Config
 from wpiformat.eofnewline import EofNewline
 from wpiformat.gtestname import GTestName
 from wpiformat.includeguard import IncludeGuard
-from wpiformat.includeorder import IncludeOrder
 from wpiformat.javaclass import JavaClass
 from wpiformat.jni import Jni
 from wpiformat.licenseupdate import LicenseUpdate
 from wpiformat.lint import Lint
 from wpiformat.pyformat import PyFormat
-from wpiformat.stdlib import Stdlib
 from wpiformat.task import BatchTask, PipelineTask, StandaloneTask, Task
 from wpiformat.usingdeclaration import UsingDeclaration
 from wpiformat.usingnamespacestd import UsingNamespaceStd
@@ -45,7 +43,9 @@ def filter_ignored_files(names):
         stdout=subprocess.PIPE,
     )
     if proc.returncode == 128:
-        raise subprocess.CalledProcessError
+        raise subprocess.CalledProcessError(
+            proc.returncode, proc.args, proc.stdout, proc.stderr
+        )
 
     output_list = proc.stdout.decode().split("\n")
 
@@ -318,7 +318,7 @@ def main():
         "-list-changed-files",
         dest="list_changed_files",
         action="store_true",
-        help="same as list-all-files, but list only files changed from main branch",
+        help="same as -list-all-files, but list only files changed from default branch",
     )
     # mp.Pool() uses WaitForMultipleObjects() to wait for subprocess completion
     # on Windows. WaitForMultipleObjects() cannot wait on more then 64 events at
@@ -334,13 +334,6 @@ def main():
         default=cpu_count,
         help="number of jobs to run (default is number of cores)",
     )
-    parser.add_argument(
-        "-clang",
-        dest="clang_version",
-        type=str,
-        default="",
-        help='version suffix for system clang-format (invokes "clang-format-CLANG_VERSION" or PyPi\'s clang-format if no suffix provided)',
-    )
     tidy_group = parser.add_mutually_exclusive_group()
     tidy_group.add_argument(
         "-tidy-changed",
@@ -384,12 +377,6 @@ def main():
     )
     args = parser.parse_args()
 
-    # TODO: Remove after deprecation cycle
-    if args.clang_version:
-        print(
-            'warning: "-clang" flag is deprecated for removal in favor of PyPI\'s clang-format and clang-tidy packages'
-        )
-
     # tidy requires compile_commands.json
     if args.tidy_all or args.tidy_changed:
         ccloc = os.path.join(args.compile_commands, "compile_commands.json")
@@ -454,28 +441,30 @@ def main():
             else:
                 print(f"warning: {f}: Broken symlink")
 
-    # Determine name of main branch for generated file comparisons
-    branch_options = ["master", "main"]
-    main_branch = ""
+    # Determine name of default branch for generated file comparisons
+    branch_options = ["origin/HEAD", "main", "master"]
+    default_branch = ""
     for branch in branch_options:
         proc = subprocess.run(
             ["git", "rev-parse", "-q", "--verify", branch], stdout=subprocess.DEVNULL
         )
         if proc.returncode == 0:
-            main_branch = branch
+            default_branch = branch
             break
 
-    if not main_branch:
+    if not default_branch:
         print(
             f"error: One of the following branches is required for generated file comparisons, but none exist: {branch_options}."
         )
         sys.exit(1)
 
     # Create list of all changed files
-    output_list = subprocess.check_output(
-        ["git", "diff", "--name-only", f"{main_branch}..."], encoding="ascii"
-    ).split()
-    changed_file_list = [root_path + os.sep + line.strip() for line in output_list]
+    changed_file_list = [
+        root_path + os.sep + os.path.normpath(line.rstrip())
+        for line in subprocess.check_output(
+            ["git", "diff", "--name-only", f"{default_branch}..."], encoding="ascii"
+        ).split()
+    ]
 
     # Don't run tasks on modifiable or generated files
     work = []
@@ -486,7 +475,11 @@ def main():
             continue
         if config_file.is_generated_file(name):
             # Emit warning if a generated file was editted
-            if name in changed_file_list:
+            if (
+                name in changed_file_list
+                and not args.list_all_files
+                and not args.list_changed_files
+            ):
                 print("Warning: generated file '" + name + "' modified")
             continue
 
@@ -514,9 +507,8 @@ def main():
         task_pipeline = [Lint()]
         run_batch(task_pipeline, args, file_batches)
     else:
-        # IncludeOrder is run after Stdlib so any C std headers changed to C++
-        # or vice versa are sorted properly. ClangFormat is run after the other
-        # tasks so it can clean up their formatting.
+        # ClangFormat is run after the other tasks so it can clean up their
+        # formatting.
         task_pipeline = [
             BraceComment(),
             CIdentList(),
@@ -525,12 +517,10 @@ def main():
             IncludeGuard(),
             LicenseUpdate(),
             JavaClass(),
-            Stdlib(),
-            IncludeOrder(),
             UsingDeclaration(),
             UsingNamespaceStd(),
             Whitespace(),
-            ClangFormat(args.clang_version),
+            ClangFormat(),
             Jni(),  # Fixes clang-format formatting
         ]
         run_pipeline(task_pipeline, args, files)
@@ -546,7 +536,6 @@ def main():
             files = list(set(files) & set(changed_file_list))
         task_pipeline = [
             ClangTidy(
-                args.clang_version,
                 args.compile_commands,
                 args.tidy_extra_args.split(",") if args.tidy_extra_args else [],
             )
